"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.patchRequest = exports.putRequest = exports.postRequest = exports.getRequest = exports.request = void 0;

var _makeRequest = require("./makeRequest.js");

var _baseUrl = require("../services/baseUrl.js");

var _headers = require("../services/headers.js");

var _validateRequiredParams = require("./validateRequiredParams.js");

var _validateBaseUrl = require("./validateBaseUrl.js");

var _validatePayload = require("./validatePayload.js");

var _constants = require("../constants/constants.js");

var request = function request(urlMaker) {
  var method = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _constants.GET;
  var requestInterface = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var fetchMaker = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : _makeRequest.makeRequest;
  return function () {
    try {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      var _args$filter = args.filter(function (arg) {
        return _typeof(arg) === 'object';
      }),
          _args$filter2 = _slicedToArray(_args$filter, 2),
          urlParams = _args$filter2[0],
          _args$filter2$ = _args$filter2[1],
          payload = _args$filter2$ === void 0 ? {} : _args$filter2$;

      var customBaseUrl = args.find(function (arg) {
        return typeof arg === 'string';
      }) || (0, _baseUrl.get)();
      var resource = (0, _validateBaseUrl.validateBaseUrl)(customBaseUrl);
      var url = typeof urlMaker === 'function' ? urlMaker(urlParams) : urlMaker || '';
      var validUrl = (0, _validateRequiredParams.validateRequiredParams)("".concat(resource).concat(url));
      var requestParams = {
        method: method,
        headers: (0, _headers.get)()
      };

      if (Object.keys(payload).length > 0) {
        requestParams = _objectSpread({}, requestParams, {
          body: (0, _validatePayload.validatePayload)(requestInterface, payload, method)
        });
      }

      return fetchMaker(validUrl, requestParams);
    } catch (err) {
      return Promise.reject(err);
    }
  };
};

exports.request = request;

var getRequest = function getRequest(urlMaker, fetchMaker) {
  return request(urlMaker, _constants.GET, fetchMaker);
};

exports.getRequest = getRequest;

var postRequest = function postRequest(urlMaker, requestInterface, fetchMaker) {
  return request(urlMaker, _constants.POST, requestInterface, fetchMaker);
};

exports.postRequest = postRequest;

var putRequest = function putRequest(urlMaker, requestInterface, fetchMaker) {
  return request(urlMaker, _constants.PUT, requestInterface, fetchMaker);
};

exports.putRequest = putRequest;

var patchRequest = function patchRequest(urlMaker, requestInterface, fetchMaker) {
  return request(urlMaker, _constants.PATCH, requestInterface, fetchMaker);
};

exports.patchRequest = patchRequest;