"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sdkRequest = void 0;

var _onSdkAvailable = require("../../connect/onSdkAvailable.js");

var _index = require("../../v0/src/index.js");

const startLoader = loaderInstance => {
  (0, _onSdkAvailable.onSdkAvailable)($sdk => {
    $sdk.dispatch({
      type: 'START_LOADER',
      loaderInstance
    });
  });
};

const stopLoader = loaderInstance => {
  (0, _onSdkAvailable.onSdkAvailable)($sdk => {
    $sdk.dispatch({
      type: 'STOP_LOADER',
      loaderInstance
    });
  });
};

const errorHandler = (instance, responseOrError) => {
  const {
    status,
    statusText,
    data
  } = responseOrError;

  if (status != null && statusText != null) {
    if (status >= 400) {
      (0, _onSdkAvailable.onSdkAvailable)($sdk => {
        $sdk.dispatch({
          type: 'SET_INSTANCE_NETWORK_ERROR',
          instance
        });
      });
    } else if (data != null && Array.isArray(data.messages) && data.messages.length > 0) {
      (0, _onSdkAvailable.onSdkAvailable)($sdk => {
        $sdk.dispatch({
          type: 'SET_INSTANCE_ERROR',
          instance,
          errors: data.messages
        });
      });
    } else {
      (0, _onSdkAvailable.onSdkAvailable)($sdk => {
        $sdk.dispatch({
          type: 'CLEAN_INSTANCE_ERROR',
          instance
        });
      });
    }
  }

  return undefined;
};

const requestService = (requestThunk, instance, token) => {
  if (instance) {
    startLoader(instance.id);
  }

  _index.authorization.set(_index.BEARER, token);

  _index.headers.append('Content-type', 'application/json');

  return requestThunk().then(data => {
    if (instance) {
      stopLoader(instance.id);
      errorHandler(instance.id, data);
    }

    return data;
  }).catch(() => {
    if (instance) {
      stopLoader(instance.id);
      (0, _onSdkAvailable.onSdkAvailable)($sdk => {
        $sdk.dispatch({
          type: 'SET_INSTANCE_NETWORK_ERROR',
          instance: instance.id
        });
      });
    }
  });
};

const sdkRequest = (requestThunk, instance, token) => requestService(requestThunk, instance, token);

exports.sdkRequest = sdkRequest;