import * as merchantService from '../../core/services/merchantService.js';
import * as merchantModel from '../../models/merchantModels.js';
import * as transactionsService from '../../core/services/transactionsService.js';
export var getMerchantContacts = function getMerchantContacts(requestParams, instance) {
  return function (dispatch) {
    merchantService.getContacts(requestParams, instance).then(function (response) {
      dispatch({
        type: 'GET_MERCHANT_CONTACTS',
        data: merchantModel.contactsModel(response.data)
      });
    });
  };
};
export var putMerchantContacts = function putMerchantContacts(requestParams, instance) {
  return function (dispatch) {
    merchantService.putContacts(requestParams, instance).then(function (response) {
      dispatch({
        type: 'PUT_MERCHANT_CONTACTS',
        data: response.data
      });
    });
  };
};
export var getMerchantPartners = function getMerchantPartners(requestParams, instance) {
  return function (dispatch) {
    merchantService.getPartners(requestParams, instance).then(function (response) {
      dispatch({
        type: 'GET_MERCHANT_PARTNERS',
        data: merchantModel.partnersModel(response)
      });
    });
  };
};
export var getMerchantAddresses = function getMerchantAddresses(requestParams, instance) {
  return function (dispatch) {
    merchantService.getAddresses(requestParams, instance).then(function (response) {
      dispatch({
        type: 'GET_MERCHANT_ADDRESSES',
        data: merchantModel.addressesModel(response.data)
      });
    });
  };
};
export var getMerchantInfo = function getMerchantInfo(requestParams, instance) {
  return function (dispatch) {
    merchantService.getInfo(requestParams, instance).then(function (response) {
      dispatch({
        type: 'GET_MERCHANT_INFO',
        data: merchantModel.infoModel(response.data, requestParams.stonecode)
      });
    });
  };
};
export var patchMerchantInfo = function patchMerchantInfo(requestParams, instance) {
  return function (dispatch) {
    merchantService.patchInfo(requestParams, instance).then(function (response) {
      dispatch({
        type: 'PATCH_MERCHANT_FANTASY_NAME',
        data: response.data.fantasyName
      });
    });
  };
};
export var getMerchantBankInfo = function getMerchantBankInfo(requestParams, instance) {
  return function (dispatch) {
    var promises = [merchantService.getAvailableBanks(requestParams, instance), merchantService.getBankInfo(requestParams, instance)];
    Promise.all(promises).then(function (responses) {
      dispatch({
        type: 'GET_MERCHANT_BANK_INFO',
        data: merchantModel.bankInfoModel(responses)
      });
    });
  };
};
export var updateBankAccounts = function updateBankAccounts(requestParams, instance) {
  return function (dispatch) {
    merchantService.putBankAccounts(requestParams, instance).then(function (response) {
      dispatch({
        type: 'PUT_MERCHANT_BANK_INFO',
        data: response.data
      });
    });
  };
};
export var getMerchantFees = function getMerchantFees(requestParams, instance) {
  return function (dispatch) {
    var promises = [transactionsService.getTransactionProfiles(requestParams, instance), transactionsService.getBrands(requestParams, instance), merchantService.getFees(requestParams, instance)];
    Promise.all(promises).then(function (responses) {
      dispatch({
        type: 'GET_MERCHANT_FEES',
        data: merchantModel.feesModel(responses)
      });
    });
  };
};