import { onSdkAvailable } from '../../connect/onSdkAvailable.js';
import { authorization, headers, BEARER } from '../../v0/src/index.js';

const startLoader = (loaderInstance) => {
  onSdkAvailable(($sdk) => {
    $sdk.dispatch({
      type: 'START_LOADER',
      loaderInstance,
    });
  });
};

const stopLoader = (loaderInstance) => {
  onSdkAvailable(($sdk) => {
    $sdk.dispatch({
      type: 'STOP_LOADER',
      loaderInstance,
    });
  });
};

const errorHandler = (instance, responseOrError) => {
  const { status, statusText, data } = responseOrError;

  if (status != null && statusText != null) {
    if (status >= 400) {
      onSdkAvailable(($sdk) => {
        $sdk.dispatch({
          type: 'SET_INSTANCE_NETWORK_ERROR',
          instance,
        });
      });
    } else if (data != null &&
      Array.isArray(data.messages) && data.messages.length > 0) {
      onSdkAvailable(($sdk) => {
        $sdk.dispatch({
          type: 'SET_INSTANCE_ERROR',
          instance,
          errors: data.messages,
        });
      });
    } else {
      onSdkAvailable(($sdk) => {
        $sdk.dispatch({
          type: 'CLEAN_INSTANCE_ERROR',
          instance,
        });
      });
    }
  }

  return undefined;
};

const requestService = (requestThunk, instance, token) => {
  if (instance) {
    startLoader(instance.id);
  }

  authorization.set(BEARER, token);
  headers.append('Content-type', 'application/json');

  return requestThunk()
    .then((data) => {
      if (instance) {
        stopLoader(instance.id);
        errorHandler(instance.id, data);
      }
      return data;
    })
    .catch(() => {
      if (instance) {
        stopLoader(instance.id);

        onSdkAvailable(($sdk) => {
          $sdk.dispatch({
            type: 'SET_INSTANCE_NETWORK_ERROR',
            instance: instance.id,
          });
        });
      }
    });
};

export const sdkRequest = (requestThunk, instance, token) =>
  requestService(requestThunk, instance, token);
