import { globalReducer } from './globalReducer.js';

describe('globalReducer', () => {
  it('Should increment loader to 1.', () => {
    const state = {
      loaders: {},
    };
    const action = {
      type: 'START_LOADER',
      loaderInstance: 'mock',
    };
    expect(globalReducer(state, action))
      .to.eql({ loaders: { mock: 1 } });
  });

  it('Should decrement loader to 0.', () => {
    const state = {
      loaders: {
        mock: 1,
      },
    };
    const action = {
      type: 'STOP_LOADER',
      loaderInstance: 'mock',
    };
    expect(globalReducer(state, action))
      .to.eql({ loaders: { mock: 0 } });
  });

  it('Should trigger an API error.', () => {
    const state = {
      errors: {
        comp: [],
      },
    };
    const action = {
      type: 'SET_INSTANCE_ERROR',
      instance: 'comp',
      errors: ['this action got an error!'],
    };
    expect(globalReducer(state, action))
      .to.eql({
        errors: {
          comp: ['this action got an error!'],
        },
      });
  });

  it('Should trigger a network error.', () => {
    const state = {
      errors: {
        comp: [],
      },
    };
    const action = {
      type: 'SET_INSTANCE_NETWORK_ERROR',
      instance: 'comp',
    };
    expect(globalReducer(state, action).errors.comp.length)
      .to.equal(1);
  });

  it('Should clean instance errors.', () => {
    const state = {
      errors: {
        comp: ['old error.'],
      },
    };
    const action = {
      type: 'CLEAN_INSTANCE_ERROR',
      instance: 'comp',
    };
    expect(globalReducer(state, action))
      .to.eql({
        errors: {
          comp: [],
        },
      });
  });
});
