import { validatePayload } from './validatePayload.js';
import { POST, PATCH } from '../constants/constants.js';

const validPayload = {
  data: 'test',
  num: 45,
};

const partiallyValidPayload = {
  data: 'test',
};

const invalidPayload = {
  data: 25,
  num: true,
};

const validArrayPayload = [
  { data: 'test', num: 45 },
  { data: 'test', num: 45 },
  { data: 'test', num: 45 },
];

const invalidArrayPayload = [
  { data: 'test', num: 45 },
  { data: 25 },
  { data: 'test', num: 45 },
];

const validModel = {
  data: String,
  num: Number,
};

describe('Validate payload helper', () => {
  it('Should return the payload if it matches the model.', () => {
    expect(validatePayload(validModel, validPayload))
      .to.equal(validPayload);
  });

  it('Should throw if the payload does not match the model.', () => {
    expect(() => validatePayload(validModel, invalidPayload))
      .to.throw();
  });

  it('Should validate each item of a payload if it is an array.', () => {
    expect(validatePayload(validModel, validArrayPayload))
      .to.equal(validArrayPayload);
  });

  it('Should throw if an item of an payload array ' +
    'does not match the model.', () => {
    expect(() => validatePayload(validModel, invalidArrayPayload))
      .to.throw();
  });

  it('Should return the payload if it matches the model partially ' +
    'and the requestMethod is PATCH.', () => {
    expect(validatePayload(validModel, partiallyValidPayload, PATCH))
      .to.equal(partiallyValidPayload);
  });

  it('Should throw if it matches the model partially ' +
    'and the requestMethod is not PATCH.', () => {
    expect(() => validatePayload(validModel, partiallyValidPayload, POST))
      .to.throw();
  });
});
